..
    This file is part of Invenio.
    Copyright (C) 2015-2018 CERN.

    Invenio is free software; you can redistribute it and/or modify it
    under the terms of the MIT License; see LICENSE file for more details.

API Docs
========

Loaders
-------

.. automodule:: invenio_config.default
   :members:

.. automodule:: invenio_config.env
   :members:

.. automodule:: invenio_config.entrypoint
  :members:

.. automodule:: invenio_config.folder
   :members:

.. automodule:: invenio_config.module
   :members:

Utilities
---------

.. automodule:: invenio_config.utils
   :members:
